==> ktoon_0.8.orig.tar.gz: ktoon-0.8/src/dlib/dcore/ispelliface.cpp <==
/***************************************************************************
 *   Copyright (C) 2006 by David Cuadrado                                  *
 *   krawek@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "ispelliface.h"

ISpellIface::ISpellIface() : SpellInterface()
{
#ifdef HAVE_ISPELL
#warning NOT IMPLEMENTED YET
#endif
}


ISpellIface::~ISpellIface()
{
}

bool ISpellIface::checkWord(const QString &word)
{
	Q_UNUSED(word);
	return false;
}

QStringList ISpellIface::suggestions(const QString &word)
{
	Q_UNUSED(word);
	return QStringList();
}

==> ktoon_0.8.1.orig.tar.gz: ktoon-0.8.1/src/dlib/dcore/ispelliface.cpp <==
/***************************************************************************
 *   Copyright (C) 2006 by David Cuadrado                                  *
 *   krawek@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "ispelliface.h"

ISpellIface::ISpellIface() : SpellInterface()
{
#ifdef HAVE_ISPELL
//#warning NOT IMPLEMENTED YET
#endif
}


ISpellIface::~ISpellIface()
{
}

bool ISpellIface::checkWord(const QString &word)
{
	Q_UNUSED(word);
	return false;
}

QStringList ISpellIface::suggestions(const QString &word)
{
	Q_UNUSED(word);
	return QStringList();
}
